@@ -1,16 +1,15 @@
 package DateTime::Calendar::Julian;
 
 use strict;
+use warnings;
 
 use vars qw($VERSION @ISA);
 
-$VERSION = '0.03';
+$VERSION = '0.101';
 
 use DateTime 0.08;
 @ISA = 'DateTime';
 
-use Params::Validate qw( validate SCALAR BOOLEAN OBJECT );
-
 sub _floor {
     my $x  = shift;
     my $ix = int $x;
@@ -28,14 +27,14 @@ my @start_of_month = (0, 31, 61, 92, 122, 153, 184, 214, 245, 275, 306, 337);
 
 # This is the difference between Julian and Gregorian calendar:
 sub _is_leap_year {
-    my ($self, $year) = @_;
+    my (undef, $year) = @_;	# Invocant unused
 
     return ($year % 4 == 0);
 }
 
 # Algorithms from http://home.capecod.net/~pbaum/date/date0.htm
-sub _ymd2rd {
-    my ($self, $y, $m, $d) = @_;
+sub _ymd2rd {	## no critic (ProhibitUnusedPrivateSubroutines)
+    my (undef, $y, $m, $d) = @_;	# Invocant unused
 
     my $adj = _floor( ($m-3)/12 );
     $m -= 12 * $adj;
@@ -45,14 +44,14 @@ sub _ymd2rd {
     return $rd;
 }
 
-sub _rd2ymd {
+sub _rd2ymd {	## no critic (ProhibitUnusedPrivateSubroutines)
     my ($self, $rd, $extra) = @_;
 
     my $z = $rd + 308;
     my $y = _floor(($z*100-25)/36525);
-    my $doy = $z - _floor(365.25*$y);
-    my $m = int((5*$doy + 456)/153);
-    my $d = $doy - $start_of_month[$m-3];
+    my $c = $z - _floor(365.25*$y);
+    my $m = int((5*$c + 456)/153);
+    my $d = $c - $start_of_month[$m-3];
     if ($m > 12) {
         $m -= 12;
         $y++;
@@ -60,6 +59,8 @@ sub _rd2ymd {
 
     if ($extra) {
         # day_of_week, day_of_year
+        my $doy = ($c + 31 + 28 - 1)%365 + 1 +
+                      ($self->_is_leap_year($y) && $m > 2);
         my $dow = (($rd + 6)%7) + 1;
         return $y, $m, $d, $dow, $doy;
     }
@@ -89,6 +90,12 @@ sub gregorian_deviation {
     return _floor($year/100)-_floor($year/400)-2;
 }
 
+sub datetime {
+    my $self = shift;
+
+    return join 'J', $self->ymd, $self->hms(':');
+}
+
 1;
 
 __END__
@@ -109,10 +116,12 @@ DateTime::Calendar::Julian - Dates in the Julian calendar
   # convert Julian->Gregorian...
 
   $dtgreg = DateTime->from_object( object => $dt );
+  print $dtgreg->datetime;  # prints '0964-10-21T00:00:00'
 
   # ... and back again
 
   $dtjul = DateTime::Calendar::Julian->from_object( object => $dtgreg );
+  print $dtjul->datetime;  # prints '0964-10-16J00:00:00'
 
 =head1 DESCRIPTION
 
@@ -123,7 +132,7 @@ methods.
 =head1 METHODS
 
 This module implements one additional method besides the ones from
-DateTime.
+DateTime, and changes the output of one other method.
 
 =over 4
 
@@ -132,6 +141,12 @@ DateTime.
 Returns the difference in days between the Gregorian and the Julian
 calendar.
 
+=item * datetime
+
+This method is now equivalent to:
+
+  $dt->ymd('-') . 'J' . $dt->hms(:)
+
 =back
 
 =head1 BACKGROUND
@@ -160,22 +175,37 @@ year 1BC (there was no year 0AD!), -1 the year 2BC, etc.
 Support for this module is provided via the datetime@perl.org email
 list. See http://lists.perl.org/ for more details.
 
+Bug reports will be accepted as RT tickets or by mail to Wyant.
+
 =head1 AUTHOR
 
 Eugene van der Pijll <pijll@gmx.net>
 
-=head1 COPYRIGHT
+Thomas R. Wyant, III F<wyant at cpan dot org>
 
-Copyright (c) 2003 Eugene van der Pijll.  All rights reserved.  This
-program is free software; you can redistribute it and/or modify it under
-the same terms as Perl itself.
+=head1 COPYRIGHT AND LICENSE
+
+Copyright (c) 2003 Eugene van der Pijll.  All rights reserved.
+
+Copyright (C) 2018-2019 Thomas R. Wyant, III
+
+This program is free software; you can redistribute it and/or modify it
+under the same terms as Perl itself.
+
+This program is distributed in the hope that it will be useful, but
+without any warranty; without even the implied warranty of
+merchantability or fitness for a particular purpose.
 
 =head1 SEE ALSO
 
-L<DateTime>
+L<DateTime|DateTime>
+
+L<DateTime::Calendar::Christian|DateTime::Calendar::Christian>
 
 datetime@perl.org mailing list
 
-http://datetime.perl.org/
+L<http://datetime.perl.org/>
 
 =cut
+
+# ex: set textwidth=72 :
